unit MemoDlg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons;

type
  TMemoDialog = class(TComponent)
  private
    FCaption: string;
    FFont: TFont;
    FBorBtns: Boolean;
    FModalResult: TModalResult;
    FReadOnly: Boolean;
    procedure SetFont(Value: TFont);
  protected
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    function Execute(Lines: TStrings): Boolean;
    property ModalResult: TModalResult read FModalResult write FModalResult;
  published
    property Caption: string read FCaption write FCaption;
    property Font: TFont read FFont write SetFont;
    property BorBtns: Boolean read FBorBtns write FBorBtns default False;
    property ReadOnly: Boolean read FReadOnly write FReadOnly;
  end;

  TMemoForm = class(TForm)
    Memo: TMemo;
    CancelBtn: TBitBtn;
    OKBtn: TBitBtn;
    WordWrapCheck: TCheckBox;
    procedure MemoChange(Sender: TObject);
    procedure WordWrapCheckClick(Sender: TObject);
  private
  public
  end;

implementation

{$R *.DFM}

constructor TMemoDialog.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FCaption := 'Memo';
  FFont := TFont.Create;
end;

destructor TMemoDialog.Destroy;
begin
  FFont.Free;
  inherited Destroy;
end;

function TMemoDialog.Execute(Lines: TStrings): Boolean;
begin
  Result := False;
  with TMemoForm.Create(Self) do
  try
    Caption := FCaption;
    Font.Assign(FFont);
    Memo.Lines.Assign(Lines);
    Memo.ReadOnly := FReadOnly;
    if FBorBtns then begin
      OKBtn.Kind := bkOK;

      CancelBtn.Kind := bkCancel;

    end;

    FModalResult := ShowModal;

  finally

    Result := FModalResult = mrOK;

    if Result then Lines.Assign(Memo.Lines);

    Free;

  end;
end;

procedure TMemoDialog.SetFont(Value: TFont);
begin
  if Value <> nil then
    FFont.Assign(Value);
end;

procedure TMemoForm.MemoChange(Sender: TObject);
begin
  OKBtn.Enabled := True;
end;

procedure TMemoForm.WordWrapCheckClick(Sender: TObject);
begin
  Memo.WordWrap := WordWrapCheck.Checked;
  if WordWrapCheck.Checked then
    Memo.ScrollBars := ssVertical else
    Memo.ScrollBars := ssBoth;
end;

end.
